Installation - heros 0.8.10 documentation

Skip to content
Back to top
View this page

# Installation

Installing HEROS is as simple as doing

    pip install heros

It will automatically install the few requirements that HEROS has (mainly eclipse-zenoh) and you are ready to create your first own HERO.

If alternatively, you prefer to keep everything neatly inside a docker container you can run

    docker run -it --network host registry.gitlab.com/atomiq-project/heros /usr/local/bin/python